@@ -1,63 +1,43 @@
-/*****************************************************************************
- * Copyright (C) 2008 by Sebastian Trueg <trueg@kde.org>                     *
- * Copyright (C) 2009 by Peter Penz <peter.penz@gmx.at>                      *
- *                                                                           *
- * This library is free software; you can redistribute it and/or             *
- * modify it under the terms of the GNU Library General Public               *
- * License as published by the Free Software Foundation; either              *
- * version 2 of the License, or (at your option) any later version.          *
- *                                                                           *
- * This library is distributed in the hope that it will be useful,           *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of            *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU         *
- * Library General Public License for more details.                          *
- *                                                                           *
- * You should have received a copy of the GNU Library General Public License *
- * along with this library; see the file COPYING.LIB.  If not, write to      *
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,      *
- * Boston, MA 02110-1301, USA.                                               *
- *****************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008 Sebastian Trueg <trueg@kde.org>
+    SPDX-FileCopyrightText: 2009 Peter Penz <peter.penz@gmx.at>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "kcommentwidget_p.h"
 #include "keditcommentdialog.h"
 
 #include <KLocalizedString>
-#include <KConfigGui/KWindowConfig>
 #include <KSharedConfig>
+#include <KWindowConfig>
 
 #include <QEvent>
-#include <QPointer>
 #include <QLabel>
-#include <QTextEdit>
+#include <QPointer>
 #include <QVBoxLayout>
 
-KCommentWidget::KCommentWidget(QWidget* parent) :
-    QWidget(parent),
-    m_readOnly(false),
-    m_label(nullptr),
-    m_sizeHintHelper(nullptr),
-    m_comment()
+KCommentWidget::KCommentWidget(QWidget *parent)
+    : QWidget(parent)
+    , m_label(new QLabel(this))
+    , m_sizeHintHelper(new QLabel(this))
 {
-    m_label = new QLabel(this);
     m_label->setWordWrap(true);
     m_label->setAlignment(Qt::AlignTop);
     connect(m_label, &QLabel::linkActivated, this, &KCommentWidget::slotLinkActivated);
 
-    m_sizeHintHelper = new QLabel(this);
     m_sizeHintHelper->hide();
 
-    QVBoxLayout* layout = new QVBoxLayout(this);
+    auto layout = new QVBoxLayout(this);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(m_label);
 
     setText(m_comment);
 }
 
-KCommentWidget::~KCommentWidget()
-{
-}
+KCommentWidget::~KCommentWidget() = default;
 
-void KCommentWidget::setText(const QString& comment)
+void KCommentWidget::setText(const QString &comment)
 {
     QString text;
     if (comment.isEmpty()) {
@@ -70,7 +50,8 @@ void KCommentWidget::setText(const QString& comment)
         if (m_readOnly) {
             text = comment.toHtmlEscaped();
         } else {
-            text = QStringLiteral("<p>") + comment.toHtmlEscaped() + QStringLiteral(" <a href=\"editComment\">") + i18nc("@label", "Edit...") + QStringLiteral("</a></p>");
+            text = QStringLiteral("<p>") + comment.toHtmlEscaped() + QStringLiteral(" <a href=\"editComment\">") + i18nc("@label", "Edit...")
+                + QStringLiteral("</a></p>");
         }
     }
 
@@ -105,7 +86,7 @@ QSize KCommentWidget::sizeHint() const
     return m_sizeHintHelper->sizeHint();
 }
 
-bool KCommentWidget::event(QEvent* event)
+bool KCommentWidget::event(QEvent *event)
 {
     if (event->type() == QEvent::Polish) {
         m_label->setForegroundRole(foregroundRole());
@@ -113,11 +94,9 @@ bool KCommentWidget::event(QEvent* event)
     return QWidget::event(event);
 }
 
-void KCommentWidget::slotLinkActivated(const QString& link)
+void KCommentWidget::slotLinkActivated(const QString &link)
 {
-    const QString caption = (link == QLatin1String("editComment")) ?
-                            i18nc("@title:window", "Edit Comment") :
-                            i18nc("@title:window", "Add Comment");
+    const QString caption = (link == QLatin1String("editComment")) ? i18nc("@title:window", "Edit Comment") : i18nc("@title:window", "Add Comment");
 
     QPointer<KEditCommentDialog> dialog = new KEditCommentDialog(this, m_comment, caption);
 
