@@ -1,27 +1,13 @@
 /*
-    <one line to give the library's name and an idea of what it does.>
-    Copyright (C) 2012  Vishesh Handa <me@vhanda.in>
+    SPDX-FileCopyrightText: 2012 Vishesh Handa <me@vhanda.in>
 
     Adapted from KFileMetadataWidget
-    Copyright (C) 2008 by Sebastian Trueg <trueg@kde.org>
-    Copyright (C) 2009-2010 by Peter Penz <peter.penz@gmx.at>
+    SPDX-FileCopyrightText: 2008 Sebastian Trueg <trueg@kde.org>
+    SPDX-FileCopyrightText: 2009-2010 Peter Penz <peter.penz@gmx.at>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    SPDX-License-Identifier: LGPL-2.1-or-later
 */
 
-
 #include "metadatafilter.h"
 
 #include <KConfig>
@@ -29,19 +15,17 @@
 
 using namespace Baloo;
 
-MetadataFilter::MetadataFilter(QObject* parent): QObject(parent)
+MetadataFilter::MetadataFilter(QObject *parent)
+    : QObject(parent)
 {
     initMetaInformationSettings();
 }
 
-MetadataFilter::~MetadataFilter()
-{
-
-}
+MetadataFilter::~MetadataFilter() = default;
 
 void MetadataFilter::initMetaInformationSettings()
 {
-    const int currentVersion = 11; // increase version, if the blacklist of disabled
+    const int currentVersion = 13; // increase version, if the blacklist of disabled
     // properties should be updated
 
     KConfig config(QStringLiteral("baloofileinformationrc"), KConfig::NoGlobals);
@@ -53,7 +37,9 @@ void MetadataFilter::initMetaInformationSettings()
         config.deleteGroup("Show");
         KConfigGroup settings = config.group("Show");
 
-        static const char* const disabledProperties[] = {
+        static const char *const disabledProperties[] = {
+            "width",
+            "height", // replaced by dimensions
             "comment",
             "contentSize",
             "depends",
@@ -80,9 +66,10 @@ void MetadataFilter::initMetaInformationSettings()
             "photoSaturation",
             "photoPixelXDimension",
             "photoPixelYDimension",
+            "photoGpsLongitude",
+            "photoGpsLatitude",
         };
 
-
         for (const auto property : disabledProperties) {
             settings.writeEntry(property, false);
         }
@@ -92,9 +79,9 @@ void MetadataFilter::initMetaInformationSettings()
     }
 }
 
-QVariantMap MetadataFilter::filter(const QVariantMap& data)
+QVariantMap MetadataFilter::filter(const QVariantMap &data)
 {
-    if( data.isEmpty() )
+    if (data.isEmpty())
         return data;
 
     QVariantMap finalData(data);
